#ifndef SHIMONOKU_INPUT_H
#define SHIMONOKU_INPUT_H

/*!
  \file
  \brief ̋̓͏

  \author Satofumi KAMIMURA

  $Id$
*/

#include "TypingMode.h"
#include "TypingTextConverter.h"


/*!
  \brief ̋̓
*/
class ShimonokuInput {
  ShimonokuInput(void);
  ShimonokuInput(const ShimonokuInput& rhs);
  ShimonokuInput& operator = (const ShimonokuInput& rhs);

  struct pImpl;
  const std::auto_ptr<pImpl> pimpl;

public:
  /*!
    \brief [hw̃IuWFNg

    \param mode [i] ^CsO[h
  */
  explicit ShimonokuInput(TypingMode mode,
                          TypingTextConverter::ConvertType type);
  ~ShimonokuInput(void);

  /*!
    \brief a̕\̏
  */
  void updateWaka(void);

  /*!
    \brief ̘âɍXV
  */
  void setNextWaka(void);

  size_t getCurrentWakaNo(void);

  /*!
    \brief ̕\
  */
  void drawWaka(void);

  /*!
    \brief ͂Ɨ̔r
  */
  void drawInput(void);

  /*!
    \brief â̓͂
  */
  bool isComplete(void);

  /*!
    \brief R|[lg̔zu
  */
  void placeComponents(void);

  /*!
    \brief R|[lg̍폜
  */
  void removeComponents(void);

  /*!
    \brief ̓R|[lg̍폜
  */
  void removeInputComponents(void);

  /*!
    \brief ͕邩ǂ

    \retval true ͕
    \retval false ͕Ȃ
  */
  bool textEmpty(void);
};

#endif /* !SHIMONOKU_INPUT_H */
